==> mollify-1.6.5.5p0.tgz: htdocs/mollify/backend/install/mysql/page_admin.php <==
<?php

	/**
	 * Copyright (c) 2008- Samuli Jrvel
	 *
	 * All rights reserved. This program and the accompanying materials
	 * are made available under the terms of the Eclipse Public License v1.0
	 * which accompanies this distribution, and is available at
	 * http://www.eclipse.org/legal/epl-v10.html. If redistributing this code,
	 * this entire header must remain intact.
	 */

	include("install/installation_page.php");
?>

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">

<html>
	<?php pageHeader("Mollify Installation", "init"); ?>
	
	<body id="page-admin">
		<?php pageBody("Installation", "2/2 Administrator User"); ?>

		<div class="content">
			<h2>
				Mollify requires an administrator user:
			</h2>
			<p>
				<form id="admin-user">
					<div class='user-data' id='admin-username'>
						<div class='title'>User name:</div>
						<input id='username' class='value' type='text' name='user' value=''>
						<div class="validation-hint" />
					</div>
					<div class='user-data' id='admin-password'>
						<div class='title'>Password:</div>
						<input id='password' class='value' type='password' name='password' value=''>
						<div class="validation-hint" />
					</div>
				</form>
			</p>
			<div class="clear"/>
			<p class="info">
				Enter username and password, and click "Install" to finish installation.
			</p>
			<p>
				<a id="button-install" href="#" class="btn green">Install</a>
			</p>
		</div>
		<?php pageFooter(); ?>
	</body>
	
	<script type="text/javascript">
		function validate() {
			$(".user-data").removeClass("invalid");
			$(".validation-hint").html("");
		
			var result = true;
			if ($("#username").val().length == 0) {
				$("#admin-username").addClass("invalid");
				$("#admin-username > .validation-hint").html("Username cannot be empty");
				result = false;
			}
			if ($("#password").val().length == 0) {
				$("#admin-password").addClass("invalid");
				$("#admin-password > .validation-hint").html("Password cannot be empty");
				result = false;
			}
			return result;
		}
		
		function init() {
			$("#button-install").click(function() {
				if (!validate()) return;
				
				setData("name", $("#username").val());
				setData("password", generate_md5($("#password").val()));
				action("install");
			});
		}
	</script>
</html>

==> mollify-1.8.9.3p6.tgz: htdocs/mollify/backend/install/mysql/page_admin.php <==
<?php

	/**
	 * Copyright (c) 2008- Samuli Jrvel
	 *
	 * All rights reserved. This program and the accompanying materials
	 * are made available under the terms of the Eclipse Public License v1.0
	 * which accompanies this distribution, and is available at
	 * http://www.eclipse.org/legal/epl-v10.html. If redistributing this code,
	 * this entire header must remain intact.
	 */

	include("install/installation_page.php");
?>

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">

<html>
	<?php pageHeader("Mollify Installation", "init"); ?>
	
	<body id="page-admin">
		<?php pageBody("Installation", "2/2 Administrator User"); ?>

		<div class="content">
			<h2>
				Mollify requires an administrator user:
			</h2>
			<p>
				<form id="admin-user">
					<div class='user-data' id='admin-username'>
						<div class='title'>User name:</div>
						<input id='username' class='value' type='text' name='user' value=''>
						<div class="validation-hint" />
					</div>
					<div class='user-data' id='admin-password'>
						<div class='title'>Password:</div>
						<input id='password' class='value' type='password' name='password' value=''>
						<div class="validation-hint" />
					</div>
				</form>
			</p>
			<div class="clear"/>
			<p class="info">
				Enter username and password, and click "Install" to finish installation.
			</p>
			<p>
				<a id="button-install" href="#" class="btn green">Install</a>
			</p>
		</div>
		<?php pageFooter(); ?>
	</body>
	
	<script type="text/javascript">
		function validate() {
			$(".user-data").removeClass("invalid");
			$(".validation-hint").html("");
		
			var result = true;
			if ($("#username").val().length == 0) {
				$("#admin-username").addClass("invalid");
				$("#admin-username > .validation-hint").html("Username cannot be empty");
				result = false;
			}
			if ($("#password").val().length == 0) {
				$("#admin-password").addClass("invalid");
				$("#admin-password > .validation-hint").html("Password cannot be empty");
				result = false;
			}
			return result;
		}
		
		function init() {
			$("#button-install").click(function() {
				if (!validate()) return;
				
				setData("name", $("#username").val());
				setData("password", $("#password").val());
				action("install");
			});
		}
	</script>
</html>
